#!/usr/bin/env python
# -*- coding: utf-8 -*-
##
##    Copyright (C) 2005 manatlan manatlan[at]gmail(dot)com
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published
## by the Free Software Foundation; version 2 only.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##

from __main__ import JPlugin

from lxml.etree import Element,ElementTree,parse,XSLT
import os,time,shutil


class Plugin(JPlugin):
    """ export to a html gallery """

    __author__ = "manatlan"
    __version__ = "1.1"

    def menuEntries(self,l):
        return [(3100,_("Export to Html"),False,self.export,None)]

    def export(self,list):
        from export import Windowexport

        # get the XSL files
        XSL = ["xsl/"+i for i in os.listdir("xsl") if i[0]!="."]

        window_export = Windowexport()

        window_export.entry.set_text( self.conf["path"] or "" )
        window_export.notebook1.set_current_page(self.conf["mode"] or 0)
        window_export.hscale_quality.set_value( float(self.conf["quality"] or 100.0) )
        window_export.hscale_size.set_value( float(self.conf["size"] or 100.0))
        window_export.setList( XSL ,self.conf["xsl"] or 0)

        ret=window_export.loop()[0]
        if ret:
            path,mode,qual,size,idXsl = ret
            self.conf["path"]=path
            self.conf["mode"]=mode
            self.conf["quality"]=qual
            self.conf["size"]=size
            self.conf["xsl"]=idXsl

            del(window_export)

            dir = path
            dirImg = os.path.join(dir,"img")
            dirThumbs = os.path.join(dir,"thumbs")

            if not os.path.isdir(dirImg):
                os.mkdir( dirImg )
            if not os.path.isdir(dirThumbs):
                os.mkdir( dirThumbs )
            try:
                nodeAlbum = Element("export")
                for pnode in list:
                    self.showProgress( list.index(pnode), len(list) , _("Exporting to Html") )
                    file = pnode.file

                    nodeImg = Element("img")

                    # Create the image File
                    #---------------------------------------------------------------
                    dest = os.path.join( dirImg, pnode.name)

                    # to be sure the destination is not present
                    # to avoid renaming process of the follow
                    if os.path.isfile(dest): os.unlink(dest)

                    ddest=unicode(dirImg)
                    if mode==1: # reduced
                        pnode.copyTo(ddest, resize=( float(size/100),qual) )
                    else:
                        pnode.copyTo(ddest)


                    nodeImg.set("src","img/"+pnode.name)

                    # Create the Thumbs
                    #---------------------------------------------------------------
                    dest = os.path.join( dirThumbs, pnode.name)
                    if os.path.isfile(dest): os.unlink(dest)

                    pb = pnode.getThumb()
                    pb.save(dest, "jpeg", {"quality":"80"})

                    nodeImg.set("mini","thumbs/"+pnode.name)

                    nodeImg.set("albumComment",pnode.getParent().comment)
                    nodeImg.set("album",pnode.getParent().name)
                    nodeImg.set("comment",pnode.comment)
                    nodeImg.set("tags",", ".join(pnode.tags))
                    nodeImg.set("hdate",cd2rd(pnode.date))  # human date ;-)
                    nodeImg.set("date",pnode.date)

                    nodeAlbum.append(nodeImg)

                xml_doc = ElementTree(nodeAlbum)

                # save a copy of the xml used file for info (can be deleted)
                fid = open(dir+"/photos.xml","w")
                xml_doc.write(fid)
                fid.close()

                xslt_doc = parse( XSL[idXsl] )
                nodeParams = xslt_doc.xpath("//xsl:param",{"xsl":"http://www.w3.org/1999/XSL/Transform"})

                p=1
                while True:

                    # the worst way to pass a param ;-)
                    nodeParams[0].text=str(p)
                    #~ nodeParams[1].text="8"

                    style = XSLT(xslt_doc)

                    result = style.apply( xml_doc)
                    page = style.tostring(result)
                    if "body" in page:
                        open(dir+"/page%d.html" % p,"w").write(page)
                        p+=1
                    else:
                        break;
            finally:
                self.showProgress()

        return False

def cd2rd(f): #yyyymmddhhiiss -> dd/mm/yyyy hh:ii:ss
   if f:
      if len(f) == 14:
         return f[6:8]+"/"+f[4:6]+"/"+f[:4]+" "+f[8:10]+":"+f[10:12]+":"+f[12:14]
      else:
         return f[6:8]+"/"+f[4:6]+"/"+f[:4]
   else:
      return f
